require 'rails_helper'

module OCms
  RSpec.describe TemplatesController, type: :controller do
    routes { OCms::Engine.routes }
    let(:template) { create(:template) }

    context "admin doing CRUD on a template" do
      login_admin

      describe "GET new" do
        it "returns http success" do
          get :new
          expect(response).to have_http_status(:success)
        end

        it "renders the #new view" do
          get :new
          expect(response).to render_template :new
        end

        it "instantiates @template" do
          get :new
          expect(assigns(:template)).not_to be_nil
        end
      end

      describe "POST create" do
        it "increases the number of Templates by 1" do
          expect{ post :create, template: {name: RandomData.random_sentence, description: RandomData.random_paragraph, layout: RandomData.random_paragraph } }.to change(Template,:count).by(1)
        end

        it "assigns the new template to @template" do
          post :create, template: {name: RandomData.random_sentence, description: RandomData.random_paragraph, layout: RandomData.random_paragraph }
          expect(assigns(:template)).to eq Template.last
        end

        it "redirects to the new template" do
          post :create, template: {name: RandomData.random_sentence, description: RandomData.random_paragraph, layout: RandomData.random_paragraph }
          expect(response).to redirect_to edit_template_path(Template.last)
        end
      end

      describe "GET edit" do
        it "returns http success" do
          get :edit, id: template.id
          expect(response).to have_http_status(:success)
        end

        it "renders the #edit view" do
          get :edit, id: template.id
          expect(response).to render_template :edit
        end

        it "assigns template to be updated to @template" do
          get :edit, id: template.id
          template_instance = assigns(:template)

          expect(template_instance).to eq template
        end
      end

      describe "PUT update" do
        it "updates template with expected attributes" do
          new_name = RandomData.random_sentence
          new_description = RandomData.random_paragraph
          new_layout = RandomData.random_paragraph

          put :update, id: template.id, template: {name: new_name, description: new_description, layout: new_layout }

          updated_template = assigns(:template)
          expect(updated_template.id).to eq template.id
          expect(updated_template.name).to eq new_name
          expect(updated_template.description).to eq new_description
          expect(updated_template.layout).to eq new_layout
        end

        it "redirects to the updated template" do
          new_name = RandomData.random_sentence
          new_description = RandomData.random_paragraph
          new_layout = RandomData.random_paragraph

          put :update, id: template.id, template: {name: new_name, description: new_description, layout: new_layout }
          expect(response).to redirect_to edit_template_path(template)
        end
      end

      describe "DELETE destroy" do
        it "deletes the template" do
          delete :destroy, id: template.id
          count = Template.where({id: template.id}).size
          expect(count).to eq 0
        end

        it "redirects to templates index" do
          delete :destroy, id: template.id
          expect(response).to redirect_to templates_path
        end
      end
    end

  end
end
