require 'rails_helper'

RSpec.feature "Admin manages page template relationship, ", type: :feature, js: true do
  scenario 'successfully associates a page with template' do
    admin = create(:user, :admin)
    page_to_update = create(:page)
    template = create(:template)

    login admin

    click_link 'Pages'

    expect(page).to have_css 'h1', text: 'Pages'
    expect(page).to have_css 'h2', text: 'Pages'
    expect(page).to have_current_path '/o_cms/pages'

    click_link 'Edit'

    expect(page).to have_css 'h2', text: 'Edit Page'
    expect(page).to have_current_path '/o_cms/pages/1/edit'
    expect(page).to have_css 'h2', text: 'Edit Page'
    expect(page).to have_field('Title', with: page_to_update.title)
    expect(page).to have_css('option', text: template.name)

    select(template.name, :from => 'page_template_id')

    click_button 'Save'

    expect(page).to have_css '.alert', text: 'Page was updated successfully.'
    expect(page).to have_select 'page_template_id', selected: template.name

    visit '/o_cms/pages'
  end

  scenario 'successfully removes assocation between page and template' do
    admin = create(:user, :admin)
    page_to_update = create(:page, template_id: 1)
    template = create(:template)

    login admin

    click_link 'Pages'

    expect(page).to have_css 'h1', text: 'Pages'
    expect(page).to have_css 'h2', text: 'Pages'
    expect(page).to have_current_path '/o_cms/pages'

    click_link 'Edit'

    expect(page).to have_css 'h2', text: 'Edit Page'
    expect(page).to have_current_path '/o_cms/pages/1/edit'
    expect(page).to have_css 'h2', text: 'Edit Page'
    expect(page).to have_field('Title', with: page_to_update.title)
    expect(page).to have_select 'page_template_id', selected: template.name

    select('', :from => 'page_template_id')

    click_button 'Save'

    expect(page).to have_css '.alert', text: 'Page was updated successfully.'

    visit '/o_cms/pages'
  end
end
