require 'rails_helper'

RSpec.feature "Admin manages templates,", type: :feature, js: true do
  scenario 'is routed to the templates index page after clicking the navigation link' do
    admin = create(:user, :admin)

    login admin
    click_link 'Pages'
    click_link 'Templates'

    expect(page).to have_css 'h1', text: 'Templates'
    expect(page).to have_css 'h2', text: 'Templates'
    expect(page).to have_current_path '/o_cms/templates'
  end

  scenario 'successfully creates a template' do
    admin = create(:user, :admin)
    template = create(:template)

    login admin
    visit '/o_cms/templates'

    expect(page).to have_css 'h1', text: 'Templates'
    expect(page).to have_css 'h2', text: 'Templates'

    click_link 'Add Template'

    expect(page).to have_css 'h2', text: 'New Template'
    expect(page).to have_current_path '/o_cms/templates/new'

    fill_in 'Name', with: "Events Template"
    fill_in 'Slug', with: "events-template"
    fill_in 'Description', with: "Template for the events page."
    fill_in 'Layout', with: "<div class=\"events\">Events Template</div>"
    click_button 'Save'

    expect(page).to have_css 'h2', text: 'Edit Template'
    expect(page).to have_field('Name', with: 'Events Template')
    expect(page).to have_field('Description', with: "Template for the events page.")
    expect(page).to have_field('Layout', with: "<div class=\"events\">Events Template</div>")
    expect(page).to have_css '.alert', text: 'Template was saved successfully.'
  end

  scenario 'successfully edits a template' do
    admin = create(:user, :admin)
    template = create(:template)

    login admin
    visit '/o_cms/templates'

    expect(page).to have_css 'h1', text: 'Template'
    expect(page).to have_css 'h2', text: 'Template'

    click_link 'Edit'

    expect(page).to have_css 'h2', text: 'Edit Template'
    expect(page).to have_field('Name', with: template.name)
    expect(page).to have_field('Slug', with: template.slug)
    expect(page).to have_field('Description', with: template.description)
    expect(page).to have_field('Layout', with: template.layout)

    fill_in 'Name', with: "Cycling routes template"
    fill_in 'Slug', with: "cycling-routes-template"
    fill_in 'Description', with: "Routes template, featuring total distance, recomended time and map download link."
    fill_in 'Layout', with: "<div class=\"routes\"><h1>Route name</h1><h2>Distance: 200km, Time: 2 hours</h2><a href=\"http://download-link.com\">Download the Route</a></div>"
    click_button 'Save'

    expect(page).to have_css '.alert', text: 'Template was updated successfully.'
    expect(page).to have_css 'h2', text: 'Edit Template'
    expect(page).to have_field('Name', with: 'Cycling routes template')
    expect(page).to have_field('Slug', with: 'cycling-routes-template')
    expect(page).to have_field('Description', with: 'Routes template, featuring total distance, recomended time and map download link.')
    expect(page).to have_field('Layout', with: "<div class=\"routes\"><h1>Route name</h1><h2>Distance: 200km, Time: 2 hours</h2><a href=\"http://download-link.com\">Download the Route</a></div>")

    visit '/o_cms/templates'

    expect(page).to have_content 'Cycling routes template'
  end

  scenario 'successfully deletes a template' do
    admin = create(:user, :admin)
    template = create(:template)

    login admin
    visit '/o_cms/templates'

    expect(page).to have_css 'h1', text: 'Templates'
    expect(page).to have_css 'h2', text: 'Templates'

    click_link 'Edit'

    expect(page).to have_css 'h2', text: 'Edit Template'
    expect(page).to have_field('Name', with: template.name)

    click_link 'Delete'

    wait = Selenium::WebDriver::Wait.new ignore: Selenium::WebDriver::Error::NoAlertPresentError
    alert = wait.until { page.driver.browser.switch_to.alert }
    alert.accept

    expect(page).to have_css '.alert', text: template.name + '" was deleted successfully.'
    expect(page).to have_current_path '/o_cms/templates'
  end
end
