require 'rails_helper'

module OCms
  RSpec.describe Template, type: :model do
    let(:template) { create(:template) }

    it { is_expected.to have_many(:pages) }
    it { is_expected.to validate_presence_of(:name)}
    it { is_expected.to validate_length_of(:name).is_at_least(5) }

    describe "attributes" do
      it "has a name, description and layout attribute" do
        expect(template).to have_attributes(name: template.name, slug: template.slug, description: template.description, layout: template.layout)
      end
    end

    describe "#create_slug" do
      it "creates the page slug from the page name" do
        template = Template.create(name: RandomData.random_sentence, description: RandomData.random_sentence)
        expect(template.slug).to eq (template.name.parameterize)
      end

      it "does not amend the template slug if one is already entered" do
        template = Template.create(name: RandomData.random_sentence, slug: RandomData.random_slug, description: RandomData.random_sentence)
        expect(template.slug).to eq (template.slug)
      end
    end

  end
end
